@@ -827,6 +827,11 @@ void fill_running_hub_list(char *dctc_srv){
 			a=strlen(obj->d_name);
 			if((a>5)&&(!strcmp(obj->d_name+a-5,".done")))
 				continue;	
+		
+			//ignore the file that's created by DCTC in 0.84 (maybe others)	
+			a=strlen(obj->d_name);
+			if((a>5)&&(!strcmp(obj->d_name+a-9,".userinfo")))
+				continue;
 
 			//found a socket
 			if(num_dctc_clients<128){
